==> sale-3.1.7-16.jar: iot/sqls/common/flowWebHandPlan.sql <==
SELECT
 *
FROM (
	SELECT
		h.f_price_id,
		ui.f_input_date,
		mr.f_user_id hpid,
		a.f_address,
		u.f_userinfo_code,
    case when h.f_price is null then pf.f_price else h.f_price end f_price,
		mr.id,
		mr.f_userinfo_id,
		mr.f_user_name,
		mr.f_user_id,
		mr.f_userfiles_id,
		mr.f_meternumber,
		isnull(mr.f_tablebase,0) f_tablebase,
		isnull(mr.f_last_tablebase,0) f_last_tablebase,
		mr.f_insert_date,
		CONVERT(varchar(2),f_insert_date, 108) f_hour,
		mr.f_signal,
		mr.f_batterylevel,
		mr.f_valvestate,
		mr.f_magneticinterference,
		mr.f_alarmshutvalve,
		mr.f_cycleshutvalue,
		mr.f_overcurrentprotection,
		mr.f_leakageflag,
		mr.f_splitalarm,
		mr.f_XTIpllStopFlag,
		mr.f_software_version,
		mr.f_table_msg,
		mr.f_last_meter_state_msg,
		mr.f_hand_date,
		mr.f_last_hand_date,
		mr.f_upload_type,
		mr.f_jval,
		ui.f_user_type,
		ui.f_gasproperties,
		gb.f_meter_brand,
		gm.f_meter_style,
		ui.f_orgstr,
		u.f_filialeids,
		ui.f_gas_date,
		ui.f_table_state,
		h.f_balance f_balance_amount,
		isnull(h.f_oughtamount,0) f_oughtamount,
		isnull(h.f_oughtfee,0) f_oughtfee,
		h.f_curbalance,
		h.f_balance,
		h.id hid,
		ui.f_filiale,
		gb.f_alias,                                         --表厂别名
		p.f_parameter_date,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=1 ) h1,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=2 ) h2,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=3 ) h3,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=4 ) h4,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=5 ) h5,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=6 ) h6,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=7 ) h7,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=8 ) h8,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=9 ) h9,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=10 ) h10,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=11 ) h11,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=12 ) h12,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=13 ) h13,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=14 ) h14,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=15 ) h15,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=16 ) h16,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=17) h17,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=18 ) h18,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=19 ) h19,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=20 ) h20,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=21 ) h21,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=22 ) h22,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=23 ) h23,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=24 ) h24,
	    mr.f_snr,                                           --信噪比
		case when p.f_parameter_state is null then '未标记' else f_parameter_state end f_parameter_state
	FROM
		t_meteread mr
		--left join t_handplan h on h.f_meteread_id=mr.id
		LEFT JOIN t_userfiles ui ON (ui.f_userfiles_id = mr.f_userfiles_id and ui.f_meternumber = mr.f_meternumber)
		LEFT JOIN t_user_address a on ui.f_useraddress_id=a.id
		LEFT JOIN t_userinfo u ON (u.f_userinfo_id = ui.f_userinfo_id)
		left join t_gasbrand gb on ui.f_gasbrand_id = gb.id
		left join t_gasmodel gm on ui.f_gasmodel_id = gm.id
		left join (select f_meternumber,'已标记' f_parameter_state,max(f_parameter_date) f_parameter_date
		        from t_userparameter where f_parameter_state='待处理' GROUP BY f_meternumber
						having COUNT(*)>0) p
		    on ui.f_meternumber=p.f_meternumber
		left join (
				select
			  f_price_id,
			 (select CAST(f_price as varchar)+' ' from t_detailprice d where  d.f_stairprice_id=p.id for XML path('')) f_price
			from t_stairprice p where f_state='有效'
		)  pf on pf.f_price_id= ui.f_price_id
		left join (
			select
				f_price_id,
				f_meteread_id,
				f_curbalance,
				f_oughtamount,
				f_oughtfee,
				f_balance,
				id,
				cast((select cast(f_price as varchar)+' ' from t_chargeprice where f_hand_id = h1.id for xml path('')) as varchar) f_price
			from t_handplan h1
		) h on h.f_meteread_id=mr.id
WHERE
    ui.f_gasbrand_id =262 and {condition}
) A
ORDER BY
	A.f_hand_date DESC

==> sale-3.2.4.jar: iot/sqls/common/flowWebHandPlan.sql <==
SELECT
 *
FROM (
	SELECT
		h.f_price_id,
		ui.f_input_date,
		mr.f_user_id hpid,
		a.f_address,
		u.f_userinfo_code,
    case when h.f_price is null then pf.f_price else h.f_price end f_price,
		mr.id,
		mr.f_userinfo_id,
		mr.f_user_name,
		mr.f_user_id,
		mr.f_userfiles_id,
		mr.f_meternumber,
		{entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(mr.f_tablebase,0) f_tablebase,
		{entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(mr.f_last_tablebase,0) f_last_tablebase,
		mr.f_insert_date,
		CONVERT(varchar(2),f_insert_date, 108) f_hour,
		mr.f_signal,
		mr.f_batterylevel,
		mr.f_valvestate,
		mr.f_magneticinterference,
		mr.f_alarmshutvalve,
		mr.f_cycleshutvalue,
		mr.f_overcurrentprotection,
		mr.f_leakageflag,
		mr.f_splitalarm,
		mr.f_XTIpllStopFlag,
		mr.f_software_version,
		mr.f_table_msg,
		mr.f_last_meter_state_msg,
		mr.f_hand_date,
		mr.f_last_hand_date,
		mr.f_upload_type,
		mr.f_jval,
		ui.f_user_type,
		ui.f_gasproperties,
		gb.f_meter_brand,
		gm.f_meter_style,
		ui.f_orgstr,
		u.f_filialeids,
		ui.f_gas_date,
		ui.f_table_state,
		h.f_balance f_balance_amount,
		{entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(h.f_oughtamount,0) f_oughtamount,
		{entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(h.f_oughtfee,0) f_oughtfee,
		h.f_curbalance,
		h.f_balance,
		h.id hid,
		ui.f_filiale,
		gb.f_alias,                                         --表厂别名
		p.f_parameter_date,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=1 ) h1,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=2 ) h2,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=3 ) h3,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=4 ) h4,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=5 ) h5,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=6 ) h6,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=7 ) h7,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=8 ) h8,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=9 ) h9,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=10 ) h10,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=11 ) h11,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=12 ) h12,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=13 ) h13,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=14 ) h14,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=15 ) h15,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=16 ) h16,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=17) h17,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=18 ) h18,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=19 ) h19,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=20 ) h20,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=21 ) h21,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=22 ) h22,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=23 ) h23,
	(SELECT val FROM [f_splitlianxi](mr.f_nsturalgas_data,',') WHERE id=24 ) h24,
	    mr.f_snr,                                           --信噪比
		case when p.f_parameter_state is null then '未标记' else f_parameter_state end f_parameter_state
	FROM
		t_meteread mr
		--left join t_handplan h on h.f_meteread_id=mr.id
		LEFT JOIN t_userfiles ui ON (ui.f_userfiles_id = mr.f_userfiles_id and ui.f_meternumber = mr.f_meternumber)
		LEFT JOIN t_user_address a on ui.f_useraddress_id=a.id
		LEFT JOIN t_userinfo u ON (u.f_userinfo_id = ui.f_userinfo_id)
		left join t_gasbrand gb on ui.f_gasbrand_id = gb.id
		left join t_gasmodel gm on ui.f_gasmodel_id = gm.id
		left join (select f_meternumber,'已标记' f_parameter_state,max(f_parameter_date) f_parameter_date
		        from t_userparameter where f_parameter_state='待处理' GROUP BY f_meternumber
						having COUNT(*)>0) p
		    on ui.f_meternumber=p.f_meternumber
		left join (
				select
			  f_price_id,
			 (select CAST(f_price as varchar)+' ' from t_detailprice d where  d.f_stairprice_id=p.id for XML path('')) f_price
			from t_stairprice p where f_state='有效'
		)  pf on pf.f_price_id= ui.f_price_id
		left join (
			select
				f_price_id,
				f_meteread_id,
				f_curbalance,
				f_oughtamount,
				f_oughtfee,
				f_balance,
				id,
				cast((select cast(f_price as varchar)+' ' from t_chargeprice where f_hand_id = h1.id for xml path('')) as varchar) f_price
			from t_handplan h1
		) h on h.f_meteread_id=mr.id
WHERE
    ui.f_gasbrand_id =262 and {condition}
) A
ORDER BY
	A.f_hand_date DESC
